# ForensicFit
ForensicFit is created to preprocess scanned images from different tears and generate a database that is going to be used in a different machine learning approaches. This package will prepare the data in four dirrent approaches which are going to be show in the tutorial sections.

https://romerogroup.github.io/ForensicFit/
